%bcond_without sys_llvm
%bcond_without check

%global maj_ver 15
%global min_ver 0
%global patch_ver 7

%if %{with sys_llvm}
%global pkg_name flang
%global bin_suffix %{nil}
%global install_prefix %{_prefix}
%else
%global pkg_name flang%{maj_ver}
%global bin_suffix -%{maj_ver}
%global install_prefix %{_libdir}/%{name}
%endif

%global install_bindir %{install_prefix}/bin
%global install_bindir %{install_prefix}/bin
%global install_includedir %{install_prefix}/include
%global install_libdir %{install_prefix}/%{_lib}

%global flang_version %{maj_ver}.%{min_ver}.%{patch_ver}
%global flang_srcdir flang-%{flang_version}.src

# Disable LTO as this causes crash if gcc lto enabled.
%global _lto_cflags %{nil}
%global _smp_mflags -j20
%global max_link_jobs 2

Name:    %{pkg_name}
Version: %{flang_version}
Release: 1
Summary: a Fortran language front-end designed for integration with LLVM

License: Apache-2.0 WITH LLVM-exception
URL:     https://flang.llvm.org
Source0: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{flang_version}/%{flang_srcdir}.tar.xz
Source1: https://github.com/llvm/llvm-project/releases/download/llvmorg-%{flang_version}/%{flang_srcdir}.tar.xz.sig

	
Patch1: 0001-fedora-link-against-libclang-cpp.patch

BuildRequires: gcc
BuildRequires: gcc-c++
BuildRequires: cmake
BuildRequires: zlib-devel
BuildRequires: llvm-devel = %{version}
BuildRequires: llvm-test = %{version}
BuildRequires: llvm-googletest = %{version}
BuildRequires: mlir-devel = %{version}
BuildRequires: ninja-build
BuildRequires: python3-lit >= 12.0.0
BuildRequires: clang-tools-extra = %{version}

# The new flang drive requires clang-devel
BuildRequires: clang-devel = %{version}
BuildRequires: clang = %{version}

%description
 
Flang is a ground-up implementation of a Fortran front end written in modern
C++.
 
%package devel
Summary: Flang header files
Requires: %{name}%{?_isa} = %{version}-%{release}
 
%description devel
Flang header files.

%prep
%autosetup -n %{flang_srcdir} -p2

%build
mkdir -p _build
cd _build

%cmake .. -GNinja \
       -DMLIR_TABLEGEN_EXE=%{install_bindir}/mlir-tblgen \
       -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       -DCMAKE_SKIP_RPATH:BOOL=ON \
       -DCLANG_DIR=%{install_libdir}/cmake/clang \
       -DLLVM_MAIN_SRC_DIR=%{install_prefix}/src \
       -DBUILD_SHARED_LIBS:BOOL=ON \
       -DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
       -DLLVM_PARALLEL_LINK_JOBS=%{max_link_jobs} \
       -DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
       -DCMAKE_PREFIX_PATH=%{install_libdir}/cmake/llvm/ \
\
%if 0%{?__isa_bits} == 64
       -DLLVM_LIBDIR_SUFFIX=64
%else
       -DLLVM_LIBDIR_SUFFIX=
%endif

export LD_LIBRARY_PATH=%{_builddir}/%{flang_srcdir}/_build/lib
%ninja_build


%install
%ninja_install -C _build

# this is a test binary
rm -f %{buildroot}%{_bindir}/f18-parse-demo


%check

%files
%license LICENSE.TXT
%{install_bindir}/tco
%{install_bindir}/bbc
%{install_bindir}/flang-to-external-fc
%{install_bindir}/fir-opt
%{install_bindir}/flang-new
%{install_libdir}/libFortranLower.so.%{maj_ver}*
%{install_libdir}/libFortranSemantics.so.%{maj_ver}*
%{install_libdir}/libFortranCommon.so.%{maj_ver}*
%{install_libdir}/libFortranRuntime.so.%{maj_ver}*
%{install_libdir}/libFortranDecimal.so.%{maj_ver}*
%{install_libdir}/libFortranEvaluate.so.%{maj_ver}*
%{install_libdir}/libFortranParser.so.%{maj_ver}*
%{install_libdir}/libflangFrontend.so.%{maj_ver}*
%{install_libdir}/libflangFrontendTool.so.%{maj_ver}*
%{install_libdir}/libFIRBuilder.so.%{maj_ver}*
%{install_libdir}/libFIRCodeGen.so.%{maj_ver}*
%{install_libdir}/libFIRDialect.so.%{maj_ver}*
%{install_libdir}/libFIRSupport.so.%{maj_ver}*
%{install_libdir}/libFIRTransforms.so.%{maj_ver}*

%files devel
%{install_libdir}/libFortranLower.so
%{install_libdir}/libFortranParser.so
%{install_libdir}/libFortranCommon.so
%{install_libdir}/libFortranSemantics.so
%{install_libdir}/libFortran_main.a
%{install_libdir}/libFIRBuilder.so
%{install_libdir}/libFIRCodeGen.so
%{install_libdir}/libFIRDialect.so
%{install_libdir}/libFIRSupport.so
%{install_libdir}/libFIRTransforms.so
%{install_libdir}/libFortranDecimal.so
%{install_libdir}/libFortranRuntime.so
%{install_libdir}/libFortranEvaluate.so
%{install_libdir}/libflangFrontend.so
%{install_libdir}/libflangFrontendTool.so
%{install_includedir}/flang
%{install_libdir}/cmake/

%changelog
* Mon Aug 28 2023 cf-zhao <zhaochuanfeng@huawei.com> - 15.0.7-1
- Initial version.
